const path = require('path');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const CopyWebpackPlugin = require('copy-webpack-plugin');


module.exports = {
    entry: './src/main.ts',
    output: {
        path: path.resolve(__dirname, '/dist/'),
        filename: '[name]-[contenthash:4]-bundle.js',
        publicPath: '/'
    },
    module: {
        rules: [
            {
                test: /\.(js|jsx|ts|tsx)$/,
                use: ['babel-loader'],
                include: path.resolve(__dirname, '../src')
            },
            {
                test: /\.(css)$/,
                use: ['style-loader', 'css-loader', 'postcss-loader'],
                exclude: /node_modules/
            },
            {
                test: /\.(scss)$/,
                use: ['style-loader', 'css-loader', 'postcss-loader', {
                    loader: 'sass-loader',
                }],
            },
            {
                test: /\.(eot|woff|otf|svg|ttf|woff2)(\?|$)/,
                use: [{
                    loader: 'file-loader',
                    options: {
                        name: 'assets/fonts/[name]_[hash:6].[ext]',
                    }
                }],
                include:path.resolve(__dirname, '../src/assets')
            },
            {
                test: /\.(appcache|mp3|mp4|pdf|xml|doc|ppt)(\?|$)/,
                use: [{
                    loader: 'file-loader',
                    options: {
                        name: 'assets/upload/[name]_[hash:6].[ext]',
                    }
                }],
                include:path.resolve(__dirname, '../src')
            },
            {
                test: /\.(jpg|jpeg|png|gif)$/i,
                use: [{
                    loader: 'url-loader',
                    options: {
                        name: 'assets/images/[name]_[hash:6].[ext]',
                        limit: 8192
                    }
                }],
                include:path.resolve(__dirname, '../src/assets')
            },

        ]
    },
    plugins: [
        new HtmlWebpackPlugin({
            filename: 'index.html',
            favicon: './public/favicon.ico',
            template: './public/index.html',
            title: 'React-Web',
            inject: true
        }),
        new CopyWebpackPlugin({
            patterns: [
                {
                    from: './src/static',
                    to: './static',
                    globOptions:{
                        ignore: ['**/favicon.ico', '**/*.html']
                    },
                    noErrorOnMissing: true
                }
            ]
        }),

    ],
    resolve: {
        extensions: ['.ts', '.tsx', '.js', '.json', '.jsx', '.scss'],
        alias: {
            '@': path.resolve(__dirname, 'src'),
            '@assets': path.resolve(__dirname, 'src/assets'),
            '@components': path.resolve(__dirname, 'src/components'),
        }
    }
}