/**
 * webpack prod 配置
 */

const path = require('path');
const Webapck = require('webpack');
const { merge } = require('webpack-merge');
const MiniCssExtractPlugin = require('mini-css-extract-plugin');
const CssMinimizerPlugin = require('css-minimizer-webpack-plugin');
const {CleanWebpackPlugin} = require('clean-webpack-plugin');
const CopyWebpackPlugin = require('copy-webpack-plugin');
const TerserPlugin = require('terser-webpack-plugin');
// const webpackBar = require('webpackbar');
const commonConfig = require('./webpack.common');
const HtmlWebpackPlugin = require('html-webpack-plugin');

module.exports = merge(commonConfig, {
    mode: 'production',
    output: {
        publicPath: '/',
        path: path.resolve(__dirname, '..', 'dist'),
        filename: '[name].[chunkhash:8].js',
        chunkFilename: '[name].[chunkhash:8].chunk.js'
    },
    cache: {
        type: 'filesystem',
        compression: 'gzip',
        cacheDirectory: path.resolve(__dirname, '..','dist/.cache')
    },
    stats: {
        children: false
    },
    optimization: {
        minimize: true,
        minimizer: [
            new TerserPlugin({
                parallel: true,
                terserOptions: {
                    compress: true,
                    warnings: false
                }
            }),
            new CssMinimizerPlugin()
        ],
        splitChunks: {
            chunks: 'all'
        }
    },
    module: {
        rules: [
            {
                test:/\.css$/,
                use: [MiniCssExtractPlugin.loader, 'css-loader', 'postcss-loader']
            },
            {
                test: /\.s(a|c)ss$/,
                use:[MiniCssExtractPlugin.loader, 'css-loader', 'postcss-loader', 'sass-loader']
            },

        ]
    },
    plugins: [
        new CleanWebpackPlugin(),
        new Webapck.DefinePlugin({
            IS_DEV: 'false'
        }),
        new MiniCssExtractPlugin({
            filename: 'assets/css/[name].[chunkhash:8].css'
        })
    ]
})